@@ -1,12 +1,12 @@
 package Glib::Install::Files;
 
 $self = {
-          'libs' => '-L/usr/local/lib -lgobject-2.0 -lintl -lglib-2.0 ',
+          'inc' => ' -I. -I/usr/local/include -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include  -DGPERL_DISABLE_THREADSAFE ',
           'typemaps' => [
                           'typemap'
                         ],
-          'deps' => [],
-          'inc' => ' -I. -I/usr/local/include -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include  -DGPERL_DISABLE_THREADSAFE '
+          'libs' => '-L/usr/local/lib -lgobject-2.0 -lglib-2.0 -lintl ',
+          'deps' => []
         };
 
 
