@@ -1,7 +1,7 @@
 package Glib::Install::Files;
 
 $self = {
-          'inc' => ' -I. -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -I/usr/local/include  -DGPERL_DISABLE_THREADSAFE ',
+          'inc' => ' -I. -I/usr/local/include -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include  -DGPERL_DISABLE_THREADSAFE ',
           'typemaps' => [
                           'typemap'
                         ],
