@@ -5,8 +5,8 @@ $self = {
                           'typemap'
                         ],
           'inc' => ' -I. -I/usr/local/include -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include  -DGPERL_DISABLE_THREADSAFE ',
-          'deps' => [],
-          'libs' => '-L/usr/local/lib -lgobject-2.0 -lglib-2.0 -lintl '
+          'libs' => '-L/usr/local/lib -lgobject-2.0 -lglib-2.0 -lintl ',
+          'deps' => []
         };
 
 
